<?php

namespace Drupal\linkit_sharepoint\Plugin\Linkit\Matcher;

use Drupal\linkit\MatcherBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Sharepoint matcher class.
 *
 * @Matcher(
 *   id = "sharepoint_matcher",
 *   label = @Translation("Sharepoint Matcher"),
 * )
 */
class SharepointMatcher extends MatcherBase {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getMatches($string) {
    $sp = \Drupal::service('linkit_sharepoint.sharepoint');
    $items = $sp->search($string);

    $config = \Drupal::service('config.factory')->get('linkit_sharepoint.adminsettings');
    $metadata = $config->get('metadata');

    $matches = [];
    foreach ($items as $item) {
      $description = [];

      foreach ($metadata as $name => $attributes) {
        $property = $item->getProperty($name);
        if (!empty($property)) {
          $description[] = $this->t('@name: @label', [
            '@name' => $this->t($name),
            '@label' => isset($attributes[$property['Label']]) ? $this->t($attributes[$property['Label']]) : $this->t($property['Label']),
          ]);
        }
      }

      $description[] = $item->EncodedAbsUrl;

      $matches[] = [
        'title' => !empty($item->Title) ? $item->Title : urldecode(basename($item->EncodedAbsUrl)),
        'description' => implode('<br/>', $description),
        'path' => '/deliver/' . $item->Id,
        'group' => 'Sharepoint Documents',
      ];
    }
    return $matches;
  }

}
